# eric7.Plugins.VcsPlugins.vcsMercurial.LargefilesExtension.__init__

Package implementing the largefiles extension support interface.

### Global Attributes

None

### Classes

None

### Functions

getDefaults | Function to get the default values of the extension.

## getDefaults

getDefaults()

Function to get the default values of the extension.

Return:
  dictionary with default values and parameter as key

Return Type:
  dict

Up